@@ -9,16 +9,17 @@
 #'
 #' @examples
 #' test_df <- data.table(
-#'   x = c(1,2,3),
-#'   y = c(4,5,6),
-#'   z = c("a","a","b"))
+#'   x = 1:3,
+#'   y = 4:6,
+#'   z = c("a","a","b")
+#'  )
 #'
 #' test_df %>%
-#'   summarize.(count = n.(),
-#'              .by = z)
+#'   summarize.(count = n.(), .by = z)
 #'
+#' # The dplyr version `n()` also works
 #' test_df %>%
-#'   mutate.(count = n.())
+#'   summarize.(count = n(), .by = z)
 n. <- function() {
-  eval_expr(.N, env = caller_env())
+  abort("n.() should only be used inside tidytable verbs")
 }
