@@ -27,15 +27,15 @@
 #'
 #' test_df %>%
 #'   rename_with.(~ toupper(.x), .cols = c(x, double_x))
-rename_with. <- function(.df, .fn, .cols = everything(), ...) {
+rename_with. <- function(.df, .fn = NULL, .cols = everything(), ...) {
   UseMethod("rename_with.")
 }
 
 #' @export
-rename_with..data.frame <- function(.df, .fn, .cols = everything(), ...) {
-  .df <- as_tidytable(.df)
+rename_with..tidytable <- function(.df, .fn = NULL, .cols = everything(), ...) {
+  if (is.null(.fn)) return(.df)
 
-  .cols <- select_vec_chr(.df, {{ .cols }})
+  .cols <- tidyselect_names(.df, {{ .cols }})
 
   if (length(.cols) == 0) return(.df)
 
@@ -49,3 +49,9 @@ rename_with..data.frame <- function(.df, .fn, .cols = everything(), ...) {
 
   .df
 }
+
+#' @export
+rename_with..data.frame <- function(.df, .fn = NULL, .cols = everything(), ...) {
+  .df <- as_tidytable(.df)
+  rename_with.(.df, .fn, {{ .cols }}, ...)
+}
