@@ -12,7 +12,6 @@
 #' @param na.rm If TRUE, NA values will be not be part of the concatenation
 #'
 #' @export
-#' @md
 #'
 #' @examples
 #' test_df <- tidytable(a = c("a", "a", "a"),
@@ -38,9 +37,7 @@ unite. <- function(.df, col = "new_col", ..., sep = "_", remove = TRUE, na.rm =
 }
 
 #' @export
-unite..data.frame <- function(.df, col = "new_col", ..., sep = "_", remove = TRUE, na.rm = FALSE) {
-  .df <- as_tidytable(.df)
-
+unite..tidytable <- function(.df, col = "new_col", ..., sep = "_", remove = TRUE, na.rm = FALSE) {
   vec_assert(sep, character(), 1)
   vec_assert(remove, logical(), 1)
   vec_assert(na.rm, logical(), 1)
@@ -50,7 +47,7 @@ unite..data.frame <- function(.df, col = "new_col", ..., sep = "_", remove = TRU
   if (length(dots) == 0) {
     unite_cols <- names(.df)
   } else {
-    unite_cols <- select_dots_chr(.df, ...)
+    unite_cols <- tidyselect_names(.df, ...)
   }
 
   if (na.rm) {
@@ -71,4 +68,10 @@ unite..data.frame <- function(.df, col = "new_col", ..., sep = "_", remove = TRU
   .df
 }
 
+#' @export
+unite..data.frame <- function(.df, col = "new_col", ..., sep = "_", remove = TRUE, na.rm = FALSE) {
+  .df <- as_tidytable(.df)
+  unite.(.df, col = col, ..., sep = sep, remove = remove, na.rm = na.rm)
+}
+
 globalVariables("..unite_cols")
