@@ -46,6 +46,21 @@ test_that("can arrange the dataset with desc.() on chr", {
   expect_equal(desc_df, check_df)
 })
 
+test_that("desc works with internal quosure", {
+  df <- data.table(x = c(4,3,9,7), y = 1:4)
+
+  desc_col <- quo(x)
+  desc_expr <- expr(desc(!!desc_col))
+
+  desc_df <- df %>%
+    arrange.(!!desc_expr)
+
+  check_df <- df %>%
+    arrange.(-x)
+
+  expect_equal(desc_df, check_df)
+})
+
 test_that("can arrange with multiple conditions", {
   df <- data.table(x = c(4,3,2,1), y = c("a","a","b","b"))
   df <- df %>%
